==> stealth_1.47.1.orig.tar.gz: stealth-1.47.1/scanner/read.cc <==
#include "scanner.ih"

//  SEE ALSO THE MEMBER waitForSentinel()

void Scanner::read(std::istream &src, string const &fname)
{
    ofstream target(fname.c_str());

    if (!target)
        d_reporter.exit() << "Can't open `" << fname << "' to write" << endl;

    Util::debug() << "Scanner::read(): about to read child input" << endl;

    char c;
    string partialSentinel;

    size_t length = 0;
    off_t size = 0;

    while (true)
    {
        if (!src.read(&c, 1))               // read char by char
        {
            d_quit = true;
            d_reporter.exit() << "Incomplete read from `" << fname << "'" <<
                                                                        endl;
            return;
        }

        if (!checkSize(fname, ++size))
            return;

        if (c == d_sentinel[length])       // got next sentinel char
        {
            length++;
                                            // matched the sentinel
            if (length == d_sentinel.length())
            {
                Util::debug() << "GOT Sentinel" << endl;

                string tail;                    // get the end-chars as well
                getline(src, tail);
                partialSentinel += tail;

                break;                          // so we're done.
            }
            partialSentinel += c;       // append c to the partial Sentinel
        }
        else
        {
            if (length)
            {
                target.write(partialSentinel.c_str(), length);
                partialSentinel.erase();
                length = 0;
            }
            target.write(&c, 1);
        }
    }
    testExitValue(partialSentinel);
}

==> stealth_2.02.01.orig.tar.gz: stealth-2.02.01/scanner/read.cc <==
#include "scanner.ih"

//  SEE ALSO THE MEMBER waitForSentinel()

void Scanner::read(std::istream &src, string const &fname)
{
    ofstream target(fname.c_str());

    if (!target)
        d_reporter.error() << "Can't open `" << fname << "' to write" << endl;

    imsg << "Scanner::read(): about to read child input" << endl;

    char c;
    string partialSentinel;

    size_t length = 0;
    off_t size = 0;

    while (true)
    {
        if (!src.read(&c, 1))               // read char by char
        {
            d_quit = true;
            d_reporter.error() << "Incomplete read from `" << fname << "'" <<
                                                                        endl;
            return;
        }

        if (!checkSize(fname, ++size))
            return;

        if (c == d_sentinel[length])       // got next sentinel char
        {
            length++;
                                            // matched the sentinel
            if (length == d_sentinel.length())
            {
                imsg << "GOT Sentinel" << endl;

                string tail;                    // get the end-chars as well
                getline(src, tail);
                partialSentinel += tail;

                break;                          // so we're done.
            }
            partialSentinel += c;       // append c to the partial Sentinel
        }
        else
        {
            if (length)
            {
                target.write(partialSentinel.c_str(), length);
                partialSentinel.erase();
                length = 0;
            }
            target.write(&c, 1);
        }
    }
    testExitValue(partialSentinel);
}
